<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "renax";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'renax/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
		'class'                => 'admin-color-pimax',
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'Renax Options', 'renax' ),
        'page_title'           => esc_html__( 'Renax Options', 'renax' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => 'AIzaSyCN8bSGZHdbSOXu0HbhXf8j0SnswTmbCNw',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => true,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => 90,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the renax. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vrenax Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'renax'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'renax'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    
    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( esc_html__( '', 'renax' ), $v );
    } else {
        $args['intro_text'] = esc_html__( '', 'renax' );
    }

    // Add content after the form.
    $args['footer_text'] = esc_html__( '', 'renax' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Support', 'renax' ),
            'content' => esc_html__( 'Send us a mail by using our item support form.', 'renax' )
        ),
        
    );
    Redux::set_help_tab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( 'Send us a mail by using our item support form.', 'renax' );
    Redux::set_help_sidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // ACTUAL DECLARATION OF SECTIONS
                Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'General Settings', 'renax' ),
                    'desc'   => esc_html__( '', 'renax' ),
                    'icon'   => 'el el-icon-home-alt',
                    // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                    'fields' => array(
							array(
								'id' => 'notice_ajax_loading',
								'type' => 'info',
								'notice' => true,
								'style' => 'success',
								'title' => esc_html__('Content Protector, Gutenberg Editor, Custom Cursor & Parent Menu URL', 'renax'),
								'desc' => esc_html__('Enable/ Disable Custom Cursor, Gutenberg Editor, Content Protector & Parent Menu URL of your site.', 'renax')
							),
						
							array(
								'id' => 'opt_theme_gutenberg',
								'type' => 'button_set',
								'title' => esc_attr__('Gutenberg Editor', 'renax'),
								'subtitle' => esc_attr__('Enable/ Disable Gutenberg Editor.', 'renax'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('Disable', 'renax'),
									'st2' => esc_html__('Enable', 'renax'),
								),
								'default'  => 'st1'
							),
						
							array(
								'id' => 'custom_cursor_opt',
								'type' => 'button_set',
								'title' => esc_html__('Custom Cursor', 'renax'),
								'subtitle' => esc_html__('', 'renax'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('Disable', 'renax'),
									'st2' => esc_html__('Enable', 'renax'),
								),
								'default'  => 'st1'
							),
						
							array(
								'id' => 'content_protector',
								'type' => 'button_set',
								'title' => esc_attr__('Content Protector', 'renax'),
								'subtitle' => esc_attr__('Not affected for the logged in user.', 'renax'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('Disable', 'renax'),
									'st2' => esc_html__('Enable', 'renax'),
								),
								'default'  => 'st1'
							),
						
							
						
							array(
								'id' => 'notice_site_preloader_opt',
								'type' => 'info',
								'notice' => true,
								'style' => 'success',
								'title' => esc_html__('Site Preloader Options', 'renax'),
								'desc' => esc_html__('Enable/ Disable preloader of your site.', 'renax')
							),
						
							array(
								'id' => 'site_preloader',
								'type' => 'button_set',
								'title' => esc_attr__('Preloader', 'renax'),
								'subtitle' => esc_attr__('', 'renax'),
								'desc' => '',
								'options' => array(
										'st1'=> esc_html__('Enable', 'renax'),
										'st2' => esc_html__('Disable', 'renax'),
								),
								'default'  => 'st1'
							),
						
							array(
								'id' => 'opt_preloader_style',
								'type' => 'button_set',
								'title' => esc_html__('Preloader Style', 'renax'),
								'subtitle' => esc_html__('', 'renax'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('Style 1', 'renax'),
									'st2' => esc_html__('Style 2', 'renax'),
								),
								'default'  => 'st1',
								'required' => array('site_preloader', '=' , 'st1')
							),
						
							array(
								'id' => 'preloader_logopic',
								'type' => 'media',
								'output' => 'true',
								'title' => esc_html__('Upload Preloader Logo', 'renax'),
								'subtitle' => esc_html__('', 'renax'),
								'required' => array('opt_preloader_style', '=' , 'st2'),
								'default' => array('url' => RENAX_THEME_URL .'/includes/img/logo-dark.png'),
							),
						
							$fields = array(
								'id'       => 'opt_preloaderlogo_dimensions',
								'type'     => 'dimensions',
								'units'    => array('em','px','%'),
								'output' => array('.ptr-prel-image'),
								'title'    => __('Preloader Logo Size', 'renax'),
								'subtitle' => __('.', 'renax'),
								'desc'     => __('Optional', 'renax'),
								'default'  => array(
									'Width'   => '103', 
									'Height'  => '40'
								),
								'required' => array('opt_preloader_style', '=' , 'st2'),
							),
						
							array(
								'id' => 'notice_header_logo',
								'type' => 'info',
								'notice' => true,
								'style' => 'success',
								'title' => esc_html__('Logo Options', 'renax'),
								'desc' => esc_html__('Logo options of your site header.', 'renax')
							),
						
							array(
								'id' => 'textlogo',
								'type' => 'button_set',
								'title' => esc_html__('Select Logo Format', 'renax'),
								'subtitle' => esc_html__('', 'renax'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('Text Logo', 'renax'),
									'st2' => esc_html__('Image Logo', 'renax'),
								),
								'default'  => 'st1'
							),
						
							array(
								'id' => 'logopic',
								'type' => 'media',
								'title' => esc_html__('Upload Logo', 'renax'),
								'subtitle' => esc_html__('', 'renax'),
								'default' => array('url' => RENAX_THEME_URL .'/includes/img/logo-light.png'),
								'required' => array('textlogo', '=' , 'st2')
							),
						
							array(
								'id' => 'logopic_dark',
								'type' => 'media',
								'title' => esc_html__('Upload Dark Logo', 'renax'),
								'subtitle' => esc_html__('', 'renax'),
								'default' => array('url' => RENAX_THEME_URL .'/includes/img/logo-dark.png'),
								'required' => array('textlogo', '=' , 'st2')
							),
						
							$fields = array(
								'id'       => 'opt_logo_dimensions',
								'type'     => 'dimensions',
								'units'    => array('em','px','%'),
								'output' => array('.logo-img'),
								'title'    => __('Logo Dimensions', 'renax'),
								'subtitle' => __('.', 'renax'),
								'desc'     => __('Optional', 'renax'),
								'default'  => array(
									'Width'   => '', 
									'Height'  => ''
								),
								'required' => array('textlogo', '=' , 'st2')
							),
							$fields = array(
								'id'       => 'opt_stickylogo_dimensions',
								'type'     => 'dimensions',
								'units'    => array('em','px','%'),
								'output' => array('.nav-scroll .logo-img'),
								'title'    => __('Sticky Logo Dimensions', 'renax'),
								'subtitle' => __('.', 'renax'),
								'desc'     => __('Optional', 'renax'),
								'default'  => array(
									'Width'   => '', 
									'Height'  => ''
								),
								'required' => array('textlogo', '=' , 'st2')
							),
							array(
								'id' => 'logopic_mob',
								'type' => 'media',
								'title' => esc_html__('Upload Responsive Logo', 'renax'),
								'subtitle' => esc_html__('Logo for Mobile version.', 'renax'),
								'default' => '',
								'required' => array('textlogo', '=' , 'st2')
							),
							$fields = array(
								'id'       => 'opt_logo_mobile_dimensions',
								'type'     => 'dimensions',
								'units'    => array('em','px','%'),
								'output' => array(''),
								'title'    => esc_html__('Responsive Logo Dimensions', 'renax'),
								'subtitle' => __('Media width 768px', 'renax'),
								'desc'     => __('Optional', 'renax'),
								'default'  => array(
									'Width'   => '', 
									'Height'  => ''
								),
								'required' => array('textlogo', '=' , 'st2')
							),	
						
						array(
							'id' => 'logotext',
							'type' => 'text',
							'title' => esc_html__('Logo Text ', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'required' => array('textlogo', '=' , 'st1')
							
						),
					)
                ) );
				
				Redux::setSection( $opt_name, array(
					'icon'   => 'el el-icon-idea',
					'title'  => esc_html__( 'Header Options', 'renax' ),
					'fields' => array(					
						array(
							'id' => 'notice_site_nav_menu',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Site Navigation Options.', 'renax'),
							'desc' => esc_html__('', 'renax'),
						),						
						$fields = array(
							'id'       => 'opt_site_classic_menu_mob_wrapperdimensions',
							'type'     => 'dimensions',
							'units'    => array('%', 'px'),
							//'output' => array('body .renax-mob-menu-wrapper'),
							'title'    => esc_html__('Mobile Menu Wrapper Width.', 'renax'),
							'subtitle' => __('Default 70%.', 'renax'),
							'height' => false,
							'desc'     => __('Optional', 'renax'),
						),
						array(
							'id' => 'header_nav_parent_anchor',
							'type' => 'button_set',
							'title' => esc_html__('Parent Menu Permalink', 'renax'),
							'subtitle' => esc_html__('Enable/ Disable parent menu permalink.', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Disable', 'renax'),
								'st2' => esc_html__('Enable', 'renax'),
							),
							'default'  => 'st1',
						),
						
						array(
							'id' => 'header_nav_sticky',
							'type' => 'button_set',
							'title' => esc_html__('Sticky Navigation', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Enable', 'renax'),
								'st2' => esc_html__('Disable', 'renax'),
							),
							'default'  => 'st1',					
						),
						array(
							'id' => 'header_res_nav_sticky',
							'type' => 'button_set',
							'title' => esc_html__('Responsive Sticky Navigation', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Enable', 'renax'),
								'st2' => esc_html__('Disable', 'renax'),
								'st3' => esc_html__('Sticky On Scroll', 'renax'),
							),
							'default'  => 'st3',
						),
						array(
							'id' => 'menu_contact_info',
							'type' => 'button_set',
							'title' => esc_html__('Menu Info', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Disable', 'renax'),
								'st2' => esc_html__('Enable', 'renax'),
							),
							'default'  => 'st1',
						),						
						array(
							'id' => 'notice_header_contact_info_phone',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Contact Info', 'renax'),
							'desc' => esc_html__('', 'renax'),
							'required' => array('menu_contact_info', '=' , 'st2')
						),
																								
						array(
							'id' => 'hd_phone_text',
							'type' => 'text',
							'title' => esc_html__('Phone Text', 'renax'),
							'subtitle' => esc_html__('Ex: Need help?', 'renax'),
							'required' => array('menu_contact_info', '=' , 'st2')
						),
						array(
							'id' => 'hd_phone_number',
							'type' => 'text',
							'title' => esc_html__('Phone Number', 'renax'),
							'subtitle' => esc_html__('Ex: 855-100-444', 'renax'),
							'required' => array('menu_contact_info', '=' , 'st2')
						),
						array(
							'id' => 'logo_adjustment',
							'type' => 'info',
							'notice' => true,
							'style' => 'info',
							'title' => esc_html__('Header Logo Options', 'renax'),
							'desc' => __('Control your site logo position.', 'renax'),
							'required' => array('textlogo', '=' , 'st2')
						),
						$fields = array(
							'id'             => 'opt_main_logo_spacing',
							'type'           => 'spacing',
							'output'         => array('body:not(.is-mobile) .renax-classic-main:not(.nav-scroll) .logo img', 'body:not(.is-mobile) .renax-header:not(.scrolled) .renax-logo img'),
							'mode'           => 'margin',
							'units'          => array('px', 'em'),
							'right'   => false, 
							'bottom'  => false, 
							'left'    => false,
							'units_extended' => 'false',
							'title'          => __('Logo Top Margin', 'renax'),
							'subtitle'       => __('Default: 0px', 'renax'),
							'desc'           => __('', 'renax'),
							'default'            => array(
								'margin-top'     => '', 
								'margin-right'   => '0px', 
								'margin-bottom'  => '0px', 
								'margin-left'    => '0px',
								'units'          => 'px', 
							),
							'required' => array('textlogo', '=' , 'st2')
						),
						$fields = array(
							'id'             => 'opt_sticky_logo_spacing',
							'type'           => 'spacing',
							'output'         => array('body:not(.is-mobile) .renax-classic-main.nav-scroll .logo img', 'body:not(.is-mobile) .renax-header.scrolled .renax-logo img'),
							'mode'           => 'margin',
							'units'          => array('px', 'em'),
							'right'   => false, 
							'bottom'  => false, 
							'left'    => false,
							'units_extended' => 'false',
							'title'          => __('Sticky Logo Top Margin', 'renax'),
							'subtitle'       => __('Default: 0px', 'renax'),
							'desc'           => __('', 'renax'),
							'default'            => array(
								'margin-top'     => '', 
								'margin-right'   => '0px', 
								'margin-bottom'  => '0px', 
								'margin-left'    => '0px',
								'units'          => 'px', 
							),
							'required' => array('textlogo', '=' , 'st2')
						),
						$fields = array(
							'id'             => 'opt_mobile_sticky_logo_spacing',
							'type'           => 'spacing',
							'output'         => array(''),
							'mode'           => 'margin',
							'units'          => array('px', 'em'),
							'right'   => false, 
							'bottom'  => false, 
							'left'    => false,
							'units_extended' => 'false',
							'title'          => __('Responsive Logo Top Margin', 'renax'),
							'subtitle'       => __('Default: 0px', 'renax'),
							'desc'           => __('', 'renax'),
							'default'            => array(
								'margin-top'     => '', 
								'margin-right'   => '0px', 
								'margin-bottom'  => '0px', 
								'margin-left'    => '0px',
								'units'          => 'px', 
							),
							'required' => array('textlogo', '=' , 'st2')
						),
						array(
							'id' => 'notice_site_global_menu_width_opt',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Menu Container Options', 'renax'),
							'desc' => esc_html__('', 'renax'),
						),
								
						$fields = array(
							'id'       => 'opt_site_classic_menu_max_width',
							'type'     => 'dimensions',
							'units'    => array('px'),
							//'output' => array(''),
							'title'    => esc_html__('Menu Container Width', 'renax'),
							'subtitle' => __('', 'renax'),
							'height' => false,
							'desc'     => __('Optional', 'renax'),
							'default'  => array(
								'width'  => ''
							),
						),						
						$fields = array(
							'id'       => 'opt_site_classic_sticky_menu_max_width',
							'type'     => 'dimensions',
							'units'    => array('px'),
							//'output' => array(''),
							'title'    => esc_html__('Sticky Menu Container Width', 'renax'),
							'subtitle' => __('', 'renax'),
							'height' => false,
							'desc'     => __('Optional', 'renax'),
							'default'  => array(
								'width'  => ''
							),
						),
					)
				));	
			   
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-bullhorn',
                    'title'  => esc_html__( 'Blog & Cars Options', 'renax' ),
                    'fields' => array(
					
						array(
			                'id' => 'notice_index_layout',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Index Layout Options', 'renax'),
			                'desc' => esc_html__('', 'renax'),
						),
					
						array(
							'id' => 'index_page_style_opt',
							'type' => 'button_set',
							'title' => esc_html__('Index Layout', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Right Sidebar', 'renax'),
								'st2' => esc_html__('Left Sidebar', 'renax'),
							),
							'default'  => 'st1'
						),
					
						array(
			                'id' => 'notice_header_page_title_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Index Page Header Options', 'renax'),
			                'desc' => esc_html__('', 'renax'),
						),
					
						array(
							'id' => 'blog_background',
							'type' => 'media',
							'output' => 'true',
							'title' => esc_html__('Upload Image', 'renax'),
							'subtitle' => esc_html__('Upload index header image.', 'renax'),
							),
					
						array(
							'id' => 'blogtitle',
							'type' => 'text',
							'title' => esc_html__('Index Title ', 'renax'),
							'subtitle' => esc_html__('Write header title for index page here. Ex: Travel [span]Experience[/span]', 'renax'),
						),
					
						array(
							'id' => 'index_title_tag_opt',
							'type' => 'select',
							'title' => esc_html__('Index Title Tag', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('h1', 'renax'),
								'st2' => esc_html__('h2', 'renax'),
								'st3' => esc_html__('h3', 'renax'),
								'st4' => esc_html__('h4', 'renax'),
								'st5' => esc_html__('h5', 'renax'),
								'st6' => esc_html__('h6', 'renax'),
							),
							'default'  => 'st1'
						),
					
						array(
							'id' => 'blog_sub_title',
							'type' => 'text',
							'title' => esc_html__('Index Sub Title ', 'renax'),
							'subtitle' => esc_html__('Write header sub title for index page here. Ex: Read travel blog', 'renax'),
						),
						array(
							'id' => 'index_subtitle_tag_opt',
							'type' => 'select',
							'title' => esc_html__('Index Sub Title Tag', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('h1', 'renax'),
								'st2' => esc_html__('h2', 'renax'),
								'st3' => esc_html__('h3', 'renax'),
								'st4' => esc_html__('h4', 'renax'),
								'st5' => esc_html__('h5', 'renax'),
								'st6' => esc_html__('h6', 'renax'),
							),
							'default'  => 'st5'
						),
						
						array(
			                'id' => 'notice_post_page_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Post Details Page Option.', 'renax'),
			                'desc' => __('', 'renax'),
						),
						array(
							'id' => 'post_pagi_opt',
							'type' => 'button_set',
							'title' => esc_attr__('Post Pagination', 'renax'),
							'subtitle' => esc_attr__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Disable', 'renax'),
								'st2' => esc_html__('Enable', 'renax'),
							),
							'default'  => 'st1'
						),
						array(
			                'id' => 'notice_car_main_base',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Car Details Base Option.', 'renax'),
			                'desc' => __('If you like, you may enter custom structures for your Car details URLs here. For example, using topics as your car base would make your car details links like http://yoursiteurl/topics/sample-post/. If you leave these blank the defaults will be used.<br>After make changes save permalink settings again.', 'renax'),
						),
					
						array(
							'id' => 'car_main_base_opt',
							'type' => 'text',
							'title' => esc_html__('Car Details Base/Slug ', 'renax'),
							'subtitle' => esc_html__('Ex: topics', 'renax'),
						),
						array(
			                'id' => 'notice_cars_cat_base',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Car Category Base Option.', 'renax'),
			                'desc' => __('If you like, you may enter custom structures for your Car Categories URLs here. For example, using topics as your car_destination base would make your car destination links like http://yoursiteurl/topics/uncategorized/. If you leave these blank the defaults will be used.<br>After make changes save permalink settings again.', 'renax'),
						),
					
						array(
							'id' => 'cars_cat_base_opt',
							'type' => 'text',
							'title' => esc_html__('Car Category Base ', 'renax'),
							'subtitle' => esc_html__('Ex: topics', 'renax'),
						),
					
						array(
			                'id' => 'notice_cars_pickup_base',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Car Pickup Base Option.', 'renax'),
			                'desc' => __('If you like, you may enter custom structures for your Car Pickup URLs here. For example, using topics as your car_destination base would make your car destination links like http://yoursiteurl/topics/uncategorized/. If you leave these blank the defaults will be used.<br>After make changes save permalink settings again.', 'renax'),
						),
					
						array(
							'id' => 'cars_pickup_base_opt',
							'type' => 'text',
							'title' => esc_html__('Car Dropoff Base ', 'renax'),
							'subtitle' => esc_html__('Ex: topics', 'renax'),
						),
						
						array(
			                'id' => 'notice_cars_dropoff_base',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Car Dropoff Base Option.', 'renax'),
			                'desc' => __('If you like, you may enter custom structures for your Car Pickup URLs here. For example, using topics as your car_destination base would make your car destination links like http://yoursiteurl/topics/uncategorized/. If you leave these blank the defaults will be used.<br>After make changes save permalink settings again.', 'renax'),
						),
					
						array(
							'id' => 'cars_dropoff_base_opt',
							'type' => 'text',
							'title' => esc_html__('Car Dropoff Base ', 'renax'),
							'subtitle' => esc_html__('Ex: topics', 'renax'),
						),
						
						array(
			                'id' => 'notice_car_taxo_pages',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Car Taxonomy & Search Pages Options.', 'renax'),
			                'desc' => __('Car Taxonomy & Search pages options.', 'renax'),
						),
						
						array(
							'id' => 'car_taxo_pages_search',
							'type' => 'button_set',
							'title' => esc_html__('Search Section', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Enable', 'renax'),
								'st2' => esc_html__('Disable', 'renax'),
							),
							'default'  => 'st1'
						),
						
						array(
							'id' => 'car_taxo_pages_car_columns',
							'type' => 'select',
							'title' => esc_html__('Grid Columns', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'col-lg-6'=> esc_html__('2 Columns', 'renax'),
								'col-lg-4'=> esc_html__('3 Columns', 'renax'),
								'col-lg-3'=> esc_html__('4 Columns', 'renax'),
							),
							'default'  => 'col-lg-6',
							'required' => array('car_taxo_pages_search', '=' , 'st2'),
						),
					)
                ) );
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-bullhorn',
                    'title'  => esc_html__( 'Page & Extra Settings', 'renax' ),
                    'fields' => array(
						array(
			                'id' => 'notice_404page_options',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('404 Page Options', 'renax'),
			                'desc' => esc_html__('', 'renax'),
						),
						array(
							'id' => '404back',
							'type' => 'media',
							'output' => 'true',
							'title' => esc_html__('Upload  404 Page Background Image', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
						),
					
						array(
			                'id' => 'notice_blog_search_options',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Post Search Page Options', 'renax'),
			                'desc' => esc_html__('', 'renax'),
						),
						array(
							'id' => 'search_post_back',
							'type' => 'media',
							'output' => 'true',
							'title' => esc_html__('Upload  Post Search Page Header Image', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
						),
					
						array(
			                'id' => 'notice_cars_search_options',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Car Search Page Options', 'renax'),
			                'desc' => esc_html__('', 'renax'),
						),
						array(
							'id' => 'search_car_back',
							'type' => 'media',
							'output' => 'true',
							'title' => esc_html__('Upload  Car Search Page Header Image', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
						),
						
						array(
			                'id' => 'notice_cars_search_date_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Search From Datepicker Settings.', 'renax'),
			                'desc' => esc_html__('', 'renax'),
						),
						
						array(
							'id' => 'cars_search_cal_first_day',
							'type' => 'button_set',
							'title' => esc_attr__('Datepicker First Day', 'renax'),
							'subtitle' => esc_attr__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Sunday', 'renax'),
								'st2' => esc_html__('Monday', 'renax'),
							),
							'default'  => 'st1'
						),
						
						array(
			                'id' => 'notice_cars_search_cal_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Search From Datepicker Translation Option.', 'renax'),
			                'desc' => esc_html__('', 'renax'),
						),
						
						array(
							'id' => 'datepicker_month_translation_opt',
							'type' => 'textarea',
							'title' => esc_html__('Months Name Translation', 'renax'),
							'subtitle' => esc_html__('e.x: "January","February","March","April","May","June", "July","August","September","October","November","December"', 'renax'),
						),
						
						array(
							'id' => 'datepicker_week_translation_opt',
							'type' => 'textarea',
							'title' => esc_html__('Days Name Translation', 'renax'),
							'subtitle' => esc_html__('e.x: "Su","Mo","Tu","We","Th","Fr","Sa"', 'renax'),
						),
					)
                ) );
				
				Redux::setSection( $opt_name, array(
				'icon'   => 'el el-icon-brush',
				'title'  => esc_html__( 'Styling', 'renax' ),
				'fields' => array(               
					array(
					'id' => 'notice_site_theme_color',
					'type' => 'info',
					'notice' => true,
					'style' => 'success',
					'title' => esc_html__('Theme Color Scheme Options.', 'renax'),
					'desc' => esc_html__('Select Theme Color Scheme Style.', 'renax'),
				),						
				array(
					'id' => 'theme_color_style',
					'type' => 'button_set',
					'title' => esc_html__('Theme Color Scheme Style', 'renax'),
					'subtitle' => esc_html__('', 'renax'),
					'desc' => '',
					'options' => array(
						'st1' => esc_html__('Light Version', 'renax'),
						'st2' => esc_html__('Dark Version', 'renax'),
					),
					'default'  => 'st1'
				),
					
					array(
						'id' => 'notice_site_global_color',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Theme Global Color.', 'renax'),
						'desc' => esc_html__('', 'renax'),
					),
					array(
						'id'       => 'opt_theme_style',
						'type'     => 'color',
						'title'    => esc_html__( 'Theme Color Option', 'renax' ),
						'subtitle' => esc_html__( 'Change all global chestnut color.', 'renax' ),
						'desc'     => esc_html__( 'Change all global chestnut color.', 'renax' ),
						'output'    => array(
							'color' => '.blog2 .post-cont .calendar a:hover, .rn-empty-mob-menu-active-color .menusb li a.active, .rn-empty-menu-active-color .navbar .navbar-nav .active, .woocommerce .sidebar-page .item .features span i, .rn-df-image-banner-title .rx-header-banner-sub-title, .blog1 .item:hover .wrapper .con .category a:hover, .woocommerce form .show-password-input::after, .woocommerce-page form .show-password-input::after, .woocommerce form .show-password-input.display-password::after, .woocommerce-page form .show-password-input.display-password::after, input[type=checkbox]:after, .navbar .navbar-right .wrap .text h5 a:hover, .rn-empty-sub-menu-active-color .navbar .dropdown-menu .dropdown-item:hover, .rn-empty-sub-menu-active-color .renax-menu-helper-class ul ul .current-menu-parent > span, .rn-empty-sub-menu-active-color .renax-menu-helper-class ul ul .current-menu-parent > span, .rn-empty-sub-menu-active-color .renax-menu-helper-class ul ul .current-menu-parent > a, .rn-empty-sub-menu-active-color .renax-menu-helper-class ul ul .current-menu-parent > a,.rn-empty-sub-menu-active-color .navbar .navbar-nav ul .current-menu-item > a, .rn-empty-sub-menu-active-color .renax-menu-helper-class ul ul .current-menu-item > a, .rn-empty-sub-menu-active-color .renax-menu ul ul li a:hover, .rn-empty-sub-menu-active-color #renax-aside .renax-main-menu ul ul li a:hover, .rn-empty-sub-menu-active-color #renax-aside .renax-main-menu ul ul > li.current-menu-item > a,.blog2 .post-cont .category a:hover, .gallery-filter li:hover, .gallery-filter li.active, .contact-box .item span, .version-dark .car-types3 .item .icon .icon-w i, .widget:not(.renax_about_widget) ul li a:hover, .rx-car-list-widget i, .car-types4 .item .info .subtitle, .cars2 .item .title .details span i, .version-dark .list-icon span, .blog2 .item .title h6, .rn-empty-footer-li-color .footer-widget-area ul:not(.list-inline) li a:hover, body .video-fullscreen-wrap .rx-header-banner-con span, body .video-fullscreen-wrap .rx-header-banner-sub-title, [data-overlay-dark] .section-title span, .section-title span, .section-subtitle, .select1_inner:after, .input1_inner:after, .cars1 .item .con .details span i, .cars1 .item .con .book .price, .video-wrapper .vid .vid-butn:hover .icon, .testimonials .item i.fa-quote-left, .testimonials .item .stars, .blog1 .item .wrapper .con .category a i, .blog1 .item:hover .wrapper .con .category a i, .banner-header .rx-df-page-banner-title span, .banner-header .rx-df-page-banner-subtitle, .cars2 .car-list .item .content .cont .features span i, .cars2 .car-list .item .content .cont .book .price, .car-details .sidebar-car .item .features span i, .accordion-box .block .acc-btn .count, .accordion-box .block .acc-btn:before, .price .item h3 span, .rx-pricing-title1-class span, .team-single .cont .simpl-bord .nav-link.active, .team-single .wrapper p a:hover, .post-prev-next a i:hover, .post-prev-next a:hover, .post-prev-next a i, .comment-reply-link:hover, .rn-empty-progress-bar-color .progress-wrap::after, .rn-empty-menu-active-color .navbar .navbar-nav .nav-link:hover, .rn-empty-menu-active-color .navbar .navbar-nav li.current-menu-ancestor > .nav-link, .rn-empty-menu-active-color .navbar .navbar-nav li.current-menu-ancestor > .nav-link, .rn-empty-menu-active-color .navbar .navbar-nav li.current-menu-parent > .nav-link, .navbar .navbar-nav .current-menu-item > a,.rn-empty-menu-active-color .renax-menu-helper-class .current-menu-parent > a, .rn-empty-menu-active-color .renax-menu-helper-class .current-page-ancestor > a, .rn-empty-menu-active-color .renax-menu-helper-class .current-menu-parent > span, .rn-empty-menu-active-color .renax-menu-helper-class .current-menu-parent > span, .rn-empty-menu-active-color.dark-version .renax-menu-helper-class .current-menu-parent span.nav-dec, .rn-empty-menu-active-color .renax-menu-helper-class .current-menu-item > a, .booking_price, .woocommerce-message::before, .woocommerce-info::before, .woocommerce-error::before, .slider-grid-bg .text .subtitle, .version-dark .cars2 .item .curv-butn .icon i span, .cars3 .item .info .details span i, .cars3 .item .project-date .year, .wpcf7-form-control-wrap .select2-container:after, .contact__form input[type="date"]:after',
							'background' => '.woocommerce .sidebar-page .item .features:hover, .woocommerce .sidebar-page .item .features.active, .woocommerce .sidebar-page .item .features.is-active, .slider-fade .owl-theme .owl-nav [class*=owl-], .owl-theme .owl-nav [class*=owl-], .modal-header, .contact-box .item.active, .contact-box .item:hover, .version-dark .car-types3 .item:hover .icon .icon-w, .version-light .car-types3 .item .icon .icon-w, .version-light .services2 .item .curv-butn .icon, .version-dark .services2 .item:hover .curv-butn .icon, .version-dark .car-types4 .item:hover .curv-butn .icon, .version-light .car-types4 .item .curv-butn .icon, .version-dark .cars2 .item:hover .curv-butn .icon, .version-light .cars2 .item .curv-butn .icon, .rn-empty-footer-li-color .footer-widget-area ul:not(.list-inline) li a:after, .mc4wp-form button, .mc4wp-form input[type="submit"], .not-found .search-form:hover .form-group .search-button, .not-found .search-form .form-group .search-button, .price .item .dot-list li:before, .version-light .about .item .curv-butn .icon, .version-dark .about .item:hover .curv-butn .icon, .booking-button, .select2-container--default .select2-results__option--highlighted[aria-selected],.select2-container--default .select2-results__option[aria-selected=true], .ui-datepicker .ui-datepicker-header, .ui-state-hover, .ui-widget-content .ui-state-hover, .ui-widget-header .ui-state-hover, .ui-state-focus, .ui-widget-content .ui-state-focus, .ui-widget-header .ui-state-focus, .cars1 .owl-theme .owl-nav [class*=owl-], .price .item .rmore .arrow, .slider-grid-bg .content .item .grid-con.grid-con-active, .slider-grid-bg .content .item .grid-con:hover, .rn-empty-toggle-color .nav-button span',
							'background-color' => '.woocommerce .sidebar-page .title, .parallax-header2 .item .head, .parallax-header2 .item .cont .list .icon span, .parallax-header2 .item .cont .list .icon i,.parallax-header2 .item .cont .list .icon svg, .woocommerce span.onsale, .added_to_cart, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) button.button.alt.disabled, .pt-po-lightbox:hover, .blog2 .post-cont .category a:before, .cars3 .item:hover .img .arrow, .version-dark .button-4, .version-dark .blog2 .item:hover .curv-butn .icon, .version-light .blog2 .item .curv-butn .icon, .banner-header .post-wrapper .divider, .button-2:hover, .blog1 .item .wrapper .con .icon-btn, .blog1 .item .wrapper .date a, .button-1,.slider-fade .owl-theme .owl-dots .owl-dot.active span, .slider-fade .owl-theme .owl-dots .owl-dot:hover span, .navbar .navbar-right .wrap .icon:hover, .button-4, .cars1 .item .con .book .btn,  .owl-theme .owl-dots .owl-dot.active span, .owl-theme .owl-dots .owl-dot:hover span, .rn-empty-social-border-color .icon-footer, .team .item:hover .butn .icon, .cars2 .sidebar-list .search, .cars2 .sidebar-list .search form button, .cars2 .sidebar-list:hover .search form button, .car-details .sidebar-car .title, .btn-double > a:nth-of-type(1), .btn-double > a:nth-of-type(2), .accordion-box .block .acc-btn.active, .team-single .wrapper .cont .coll .social-icon a:hover, .blog2-sidebar .search form button, .blog2-sidebar:hover .search form button, .widget .tagcloud a:hover, .pagination-wrap li a.active, .pagination-wrap li a:hover, .rn-empty-social-border-color .social-icons li:hover, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) #respond input#submit, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) a.button, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) button.button, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) input.button, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce #respond input#submit, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce a.button, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce button.button, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce input.button,.woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) #respond input#submit.alt, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) a.button.alt, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) button.button.alt, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) input.button.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce #respond input#submit.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce a.button.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce button.button.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce input.button.alt, .version-dark .car-types1 .item:hover .curv-butn .icon, .version-light .car-types1 .item .curv-butn .icon, .wc-block-components-button:not(.is-link), body .wc-block-grid__product-add-to-cart.wp-block-button .wp-block-button__link:hover',
							'border-color' => '.slider-fade .owl-theme .owl-nav [class*=owl-], .added_to_cart, body .wc-block-grid__product-add-to-cart.wp-block-button .wp-block-button__link, body .wc-block-grid__product-add-to-cart.wp-block-button .wp-block-button__link:hover, .wc-block-components-button:not(.is-link), .owl-theme .owl-nav [class*=owl-], .car-types3 .item:hover .icon .icon-w, .car-types3 .item .icon .icon-w, .services2 .item .curv-butn .icon, .services2 .item:hover .curv-butn .icon, .car-types4 .item:hover .curv-butn .icon, .car-types4 .item .curv-butn .icon, .cars3 .item:hover .img .arrow, .cars2 .item:hover .curv-butn .icon, .cars2 .item .curv-butn .icon, .version-light .car-types1 .item .curv-butn .icon, .version-dark .button-4, .mc4wp-form input:not([type="submit"]), .rn-empty-social-border-color .social-icons li, .pagination-wrap li a.active, .pagination-wrap li a:hover, .line-vr-section, .not-found .search-form .form-group input[type="text"], .not-found .search-form .form-group input[type="search"], .not-found .search-form .form-group input[type="email"], .team-single .wrapper .cont .coll .social-icon a, .team-single .wrapper .cont .coll .social-icon a:hover, .price .item .rmore .arrow, .team .item .butn .icon, .team .item:hover .butn .icon, .rn-empty-social-border-color .icon-footer, .button-2:hover, .blog1 .item .wrapper .con .icon-btn, .video-wrapper .vid .vid-butn .icon:after, .elementor .line-vr-section, .owl-theme .owl-dots .owl-dot.active span, .owl-theme .owl-dots .owl-dot:hover span, .car-types1 .item .curv-butn .icon, .button-1, .slider-fade .owl-theme .owl-dots .owl-dot.active span, .slider-fade .owl-theme .owl-dots .owl-dot:hover span, .navbar .navbar-right .wrap .icon, .button-4, .version-dark .about .item .curv-butn .icon, .version-light .about .item .curv-butn .icon, .ui-datepicker .ui-datepicker-header, .ui-state-hover, .ui-widget-content .ui-state-hover, .ui-widget-header .ui-state-hover, .ui-state-focus, .ui-widget-content .ui-state-focus, .ui-widget-header .ui-state-focus, .cars1 .item .con .book .btn, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) #respond input#submit, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) a.button, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) button.button, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) input.button, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce #respond input#submit, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce a.button, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce button.button, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce input.button,.woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) #respond input#submit.alt, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) a.button.alt, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) button.button.alt, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) input.button.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce #respond input#submit.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce a.button.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce button.button.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce input.button.alt, .blog2 .item .curv-butn .icon, .blog2 .item:hover .curv-butn .icon',
							'border-bottom-color' => '.team-single .cont .simpl-bord.nav-tabs, .gallery-filter li.active',
							'stroke' =>'.rn-empty-progress-bar-color .progress-wrap svg.progress-circle path',
							'fill' =>'body .wc-block-components-checkbox .wc-block-components-checkbox__mark, .version-dark .list-icon svg',
							'border-top-color' =>'.rn-empty-preloader-ac-color .loader span, .woocommerce-error, .woocommerce-info, .woocommerce-message',
							'border-right-color' =>'.parallax-header2 .item .head .shape',
						),
					),
							
					array(
						'id' => 'notice_site_global_classic_menu_opt',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Classic Menu Options', 'renax'),
						'desc' => esc_html__('Classic menu Background color options.', 'renax'),
					),
							
					array(
						'id'       => 'opt_site_classic_menu_back_color',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Menu Background Color ', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
					),
					array(
						'id' => 'renax_pageid',
						'type' => 'text',
						'title' => esc_attr__('Exclude by Page ID ', 'renax'),
						'subtitle' => esc_attr__('Disable navigation background by Page ID. Keep blank for all pages. e.x: 1,2', 'renax'),
					),
							
					array(
						'id'       => 'opt_site_classic_menu_sticky_back_color',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Sticky Menu Background Color ', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background' => 'body .nav-scroll', 
						),
					),
							
					array(
						'id'       => 'opt_site_classic_menu_sub_menu_back_color_desk',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Sub Menu Background Color', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background-color' => '.navbar .dropdown-menu', 
						),
					),
							
					array(
						'id'       => 'opt_site_classic_menu_sub_menu_border_color_desk',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Menu Item Border Color', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'border-bottom-color' => '.navbar .dropdown-menu li', 
						),
					),
					
					array(
						'id' => 'notice_site_global_classic_mob_menu_opt',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Responsive Classic Menu Options', 'renax'),
						'desc' => esc_html__('Classic Menu for Mobile version.', 'renax'),
					),
							
					array(
						'id'       => 'opt_site_classic_mob_menu_bar_back_color',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Menu Bar Background Color ', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background' => '.renax-mob-menu-wrapper', 
						),
					),
					
					array(
						'id'       => 'opt_site_classic_mob_menu_back_color',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Menu Wrapper Background Color ', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background' => '.main-menu', 
						),
					),
					
					array(
						'id'       => 'opt_site_classic_mob_menu_toggle_color',
						'type'     => 'color',
						'title'    => esc_html__( 'Menu Toggle Icon Color', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background' => '.nav-button span', 
						),
					),
					array(
						'id' => 'notice_banner_back_color_opt',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => __('Header banner Background Color', 'renax'),
						'desc' => __('', 'renax')
					),
					array(
						'id'       => 'opt_banner_style_bg_color_top',
						'type'     => 'color',
						'title'    => esc_html__( 'Header Banner Background Color', 'renax' ),
						'subtitle' => esc_html__( 'Header Banner Background Color', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background' => '.banner-header', 
						),
					),
					array(
						'id'       => 'opt_banner_style_overlay_color_top',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Header Banner Overlay Color', 'renax' ),
						'subtitle' => esc_html__( 'Header Banner Overlay Color', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background' => '.banner-header[data-overlay-dark]:before, .banner-header[data-overlay-light]:before', 
						),
					),
					array(
						'id' => 'notice_site_theme_preloader',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Site Preloader Options.', 'renax'),
						'desc' => esc_html__('', 'renax'),
					),	
					array(
						'id'       => 'opt_theme_site_theme_preloader_back',
						'type'     => 'color',
						'title'    => esc_html__( 'Background Color', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background' => '.preloader-bg, #preloader, .version-light .preloader-bg, .version-light #preloader', 
						),
					),	
					array(
						'id'       => 'opt_theme_site_theme_preloader_progress_bar',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Progress Bar Background Color', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'border-color' => '.loader, .version-light .loader, .preloader__pulse', 
						),
					),
							
					array(
						'id'       => 'opt_theme_site_theme_preloader_progress_bar_active',
						'type'     => 'color',
						'title'    => esc_html__( 'Progress Bar Active Background/ Border Color', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'border-top-color' => '.loader span', 
						),
					),
					
					array(
						'id'       => 'opt_theme_site_theme_preloader_shadow_bar',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Progress Bar Shadow Color(Style 2)', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
					),
							
					array(
						'id' => 'notice_site_theme_scroll_to_top',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Scroll To Top Button Options.', 'renax'),
						'desc' => esc_html__('', 'renax'),
					),
					
					array(
						'id'       =>'opt_theme_site_theme_scroll_to_top_back_active',
						'type'     => 'color',
						'title'    => esc_html__( 'Progress Bar Active Color', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'color' => '.progress-wrap::after', 
							'stroke' => '.progress-wrap svg.progress-circle path', 
						),
					),
					array(
						'id' => 'notice_footer_back_color_opt',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => __('Footer Section', 'renax'),
						'desc' => __('', 'renax')
					),
					array(
						'id'       => 'footer_style_background_color',
						'type'     => 'color',
						'title'    => esc_html__( 'Footer Background Color', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background-color' => '.footer', 
						),	
					),					
					array(
						'id'       => 'footer_style_border_color_bottom',
						'type'     => 'color_rgba',
						'title'    => esc_html__( 'Footer Divider Color', 'renax' ),
						'subtitle' => esc_html__( 'Pick a color for the footer divider.', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'border-bottom-color' => '.footer .second-footer', 
							'border-color' => '.links.dark', 
							'background-color' => '.footer-contact-links-divider', 
						),	
					),
					
					array(
						'id'       => 'footer_style_social_back_color',
						'type'     => 'color',
						'title'    => esc_html__( 'Footer Social & Contact Info Icon Border/ Background', 'renax' ),
						'subtitle' => esc_html__( '', 'renax' ),
						'desc'     => esc_html__( '', 'renax' ),
						'output'    => array(
							'background-color' => '.social-icons li:hover, .icon-footer', 
							'border-color' => '.social-icons li, .icon-footer', 
						),	
					),
							
				)
			) );
			if (class_exists('WooCommerce')) {
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-shopping-cart-sign',
                    'title'  => esc_attr__( 'Shop Options', 'renax' ),
                    'fields' => array(
					
						array(
			                'id' => 'notice_shop_layout_info',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Product Page Layout', 'renax'),
			                'desc' => esc_html__('', 'renax')
						),
						array(
							'id' => 'shopstyle',
							'type' => 'button_set',
							'title' => esc_html__('Select Shop Layout', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => 'Remove all widgets from the widget area for the full width shop page.',
							'options' => array(
								'st1'=> esc_html__('Right Sidebar', 'renax'),
								'st2' => esc_html__('Left Sidebar', 'renax'),
							),
							'default'  => 'st1'
						),
						
						array(
							'id' => 'shopwidstyle',
							'type' => 'button_set',
							'title' => esc_html__('Select Widgets Layout', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Default', 'renax'),
								'st2' => esc_html__('Fancy', 'renax'),
							),
							'default'  => 'st1'
						),
					
					
						array(
							'id' => 'wr-shop-opt',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('Shop Page Header Options', 'renax'),
							'desc' => esc_attr__(' ', 'renax')
						),

						array(
							'id' => 'shopheaderimg',
							'type' => 'media',
							'output' => 'true',
							'title' => esc_attr__('Upload Shop Page Header Image', 'renax'),
							'subtitle' => esc_attr__('', 'renax'),
						),
					
						array(
							'id' => 'shopsubtitle',
							'type' => 'text',
							'title' => esc_attr__('Sub Title ', 'renax'),
							'subtitle' => esc_attr__('Shop page sub title', 'renax'),
						),
						
						array(
			                'id' => 'notice_shop_text_base',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Translate Options', 'travol'),
			                'desc' => __('Shop pages hard text translate options.', 'travol'),
						),
						array(
							'id' => 'opt_form_translet_7',
							'type' => 'text',
							'title' => esc_html__('/ rent per day', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
						),
					
						array(
							'id' => 'cart_placeholder_button_shop_txt',
							'type' => 'text',
							'title' => esc_html__('Book', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
						),
						
						array(
							'id' => 'wr_shop_catalog_mode',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('Others Options', 'renax'),
							'desc' => esc_attr__(' ', 'renax')
						),
					 
						array(
							'id' => 'shop_tools_main_opt',
							'type' => 'button_set',
							'title' => esc_html__('Header Tools', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('WooCoomerce Pages Only', 'renax'),
								'st2' => esc_html__('All Pages', 'renax'),
							),
							'default'  => 'st1',
						),
					
						array(
							'id' => 'pageid',
							'type' => 'text',
							'title' => esc_attr__('Show By Page ID ', 'renax'),
							'subtitle' => esc_attr__('Keep blank for all pages. e.x: 1,2', 'renax'),
							'required' => array('shop_tools_main_opt', '=' , 'st2')
						),
					
						
						array(
							'id' => 'shop_header_cart',
							'type' => 'button_set',
							'title' => esc_html__('Header Mini Cart', 'renax'),
							'subtitle' => esc_html__('Enable/ Disable Header Mini Cart Icon.', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Enable', 'renax'),
								'st2' => esc_html__('Disable', 'renax'),
							),
							'default'  => 'st1'
						),
						
						array(
							'id' => 'shop_header_account',
							'type' => 'button_set',
							'title' => esc_html__('Header My Account', 'renax'),
							'subtitle' => esc_html__('Enable/ Disable Header My Account Icon.', 'renax'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Enable', 'renax'),
								'st2' => esc_html__('Disable', 'renax'),
							),
							'default'  => 'st1'
						),
						
					)
                ) );
				}	
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-text-width',
                    'title'  => esc_attr__( 'Typography', 'renax' ),
                    'fields' => array(  


						array(
                            'id'          => 'typo_body',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Body', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('body'),
                            'units'       =>'px',
                            'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Body Text font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_p',
                            'type'        => 'typography', 
                            'title'       => esc_html__('P', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('p'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('Specify the P Text font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						
						array(
                            'id'          => 'typo_span',
                            'type'        => 'typography', 
                            'title'       => esc_html__('span', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('span'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('Specify the span Text font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_btn',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Button', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'output'      => array('body .wc-block-components-button:not(.is-link),[class*=version-] [class*=button-],.booking-button, body .wc-block-grid__product-add-to-cart.wp-block-button .wp-block-button__link, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) #respond input#submit, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) a.button, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) button.button, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) input.button, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce #respond input#submit, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce a.button, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce button.button, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce input.button, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) #respond input#submit.alt, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) a.button.alt, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) button.button.alt, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) input.button.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce #respond input#submit.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce a.button.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce button.button.alt, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce input.button.alt, .added_to_cart'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('Specify the span Text font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_btn_hv',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Button Hover', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                           'output'      => array('body .wc-block-components-button:not(.is-link):hover,[class*=version-] [class*=button-]:hover,.booking-button:hover, body .wc-block-grid__product-add-to-cart.wp-block-button .wp-block-button__link:hover, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) #respond input#submit:hover, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) a.button:hover, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) button.button:hover, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) input.button:hover, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce #respond input#submit:hover, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce a.button:hover, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce button.button:hover, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce input.button:hover, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) #respond input#submit.alt:hover, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) a.button.alt:hover, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) button.button.alt:hover, .woocommerce:where(body:not(.woocommerce-block-theme-has-button-styles)) input.button.alt:hover, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce #respond input#submit.alt:hover, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce a.button.alt:hover, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce button.button.alt:hover, :where(body:not(.woocommerce-block-theme-has-button-styles)) .woocommerce input.button.alt:hover, .added_to_cart:hover'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('Specify the span Text font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h1', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h1'),
                            'units'       =>'px',
                            'line-height'       =>false,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h1 font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h2',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h2', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h2'),
                            'units'       =>'px',
                            'line-height'       =>false,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h2 font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h3',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h3', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h3'),
                            'units'       =>'px',
                            'line-height'       =>false,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h3 font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h4',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h4', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h4'),
                            'units'       =>'px',
                            'line-height'       =>false,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h4 font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h5',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h5', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h5'),
                            'units'       =>'px',
                            'line-height'       =>false,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h5 font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h6',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h6', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h6'),
                            'units'       =>'px',
                            'line-height'       =>false,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h6 font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						
						array(
			                'id' => 'notice_critical11',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Header', 'renax'),
			                'desc' => esc_html__('', 'renax')
			            ),
						
						array(
                            'id'          => 'opt_header_default_title',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Page Header Title', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.banner-header .rx-df-page-banner-title'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('Specify the page header title font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'opt_header_default_sub_title',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Header Sub Title', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('body .banner-header .rx-df-page-banner-subtitle'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('Specify the page header sub title and catgory font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'logotextwr1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Text Logo', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('body .duru-header .logo h2'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('Specify the Logo Text font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'logotextwr2',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Sticky Text Logo', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('body .duru-header.sticky .logo h2'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('Specify the Logo Text font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'opt_hd_con_info_title',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Header Contact Info Title', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.navbar .navbar-right .wrap .text p'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'opt_hd_con_info_phone',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Header Contact Info Phone Number', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.navbar .navbar-right .wrap .text h5 a'),
                            'units'       =>'px',
							'line-height'       =>false,
							'font-style'  => false,
							'font-weight'  => true,
                            'subtitle'    => esc_html__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_navmenu_classic',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Navigation Menu', 'renax'),
			                'desc' => __('Deafult Menu Options', 'renax')
			            ),	
												
						array(
                            'id'          => 'typography_a_navmenu_item',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.navbar .navbar-nav .nav-link','.renax-menu ul li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the nav font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),

						array(
                            'id'          => 'typography_a_navmenu_item_hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover/ Active', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.navbar .navbar-nav .nav-link:hover', '.navbar .navbar-nav li.current-menu-ancestor > .nav-link', '.navbar .navbar-nav li.current-menu-ancestor > .nav-link', '.navbar .navbar-nav li.current-menu-parent > .nav-link', '.navbar .navbar-nav .current-menu-item > a','.renax-menu-helper-class .current-menu-parent > a', '.renax-menu-helper-class .current-page-ancestor > a', '.renax-menu-helper-class .current-menu-parent > span', '.renax-menu-helper-class .current-menu-parent > span', '.dark-version .renax-menu-helper-class .current-menu-parent span.nav-dec', '.renax-menu-helper-class .current-menu-item > a, .navbar .navbar-nav .active'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the nav font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
										
						array(
			                'id' => 'notice_critical1_navmenu_overall',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Navigation Menu Sub/Dropdown', 'renax'),
			                'desc' => __('Not affeced for the Sliding menu style.', 'renax')
			            ),	
						array(
                            'id'          => 'typography_a_sub_navmenu',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sub Menu Item', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.navbar .dropdown-menu .dropdown-item','.renax-menu ul ul li a', '#renax-aside .renax-main-menu ul ul li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),										
						
						array(
                            'id'          => 'typography_a_sub_navmenu_active',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sub Menu Item Hover/ Active', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.navbar .dropdown-menu .dropdown-item:hover', '.renax-menu-helper-class ul ul .current-menu-parent > span', '.renax-menu-helper-class ul ul .current-menu-parent > span', '.renax-menu-helper-class ul ul .current-menu-parent > a', '.renax-menu-helper-class ul ul .current-menu-parent > a','.navbar .navbar-nav ul .current-menu-item > a', '.renax-menu-helper-class ul ul .current-menu-item > a', '.renax-menu ul ul li a:hover', '#renax-aside .renax-main-menu ul ul li a:hover', '#renax-aside .renax-main-menu ul ul > li.current-menu-item > a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the nav font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),	
						
						
						array(
			                'id' => 'notice_critical1_stickynavmenu_classic',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Sticky Navigation Menu', 'renax'),
			                'desc' => __('Affeced for the Classic Menu style.', 'renax')
			            ),	
												
						array(
                            'id'          => 'typography_a_navmenu_sticky',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sticky Menu Item', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.nav-scroll .navbar-nav .nav-link'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the nav font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),	
						array(
                            'id'          => 'typography_a_navmenu_sticky_hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sticky Menu Item Hover/ Active', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.nav-scroll .navbar-nav .nav-link:hover', '.nav-scroll.navbar .navbar-nav li.current-menu-ancestor > .nav-link', '.nav-scroll.navbar .navbar-nav li.current-menu-ancestor > .nav-link', '.nav-scroll.navbar .navbar-nav li.current-menu-parent > .nav-link', '.nav-scroll.navbar .navbar-nav .current-menu-item > a, .nav-scroll .navbar-nav .active'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the nav font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),				
						
						array(
			                'id' => 'notice_critical1_mobilenavmenu_classic',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Mobile Menu', 'renax'),
			                'desc' => __('Affeced for the Classic Menu style.', 'renax')
			            ),	
												
						array(
                            'id'          => 'typography-a-navmenu-classic-mobile',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('[class*=version-] .menusb a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the nav font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),	
						array(
                            'id'          => 'typography-a-navmenu-classic-mobile-hov',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover/ Active', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('[class*=version-] .menusb .current-page-ancestor > a', '[class*=version-] .menusb .current-menu-item > a', '[class*=version-] .menusb .current-menu-parent > a', '[class*=version-] .menusb .current-page-ancestor > a', '[class*=version-] .menusb .current-menu-item > a','[class*=version-] .menusb a:hover, .menusb li a.active'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the nav font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),						
						array(
			                'id' => 'notice_critical1_navmenu_overall-mobile',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Navigation Menu Sub/Dropdown', 'renax'),
			                'desc' => __('Mobile Menu Options.', 'renax')
			            ),	
						array(
                            'id'          => 'typography-a-sub-navmenu-sticky',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sub Menu Item', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('body.is-mobile .navbar .dropdown-menu .dropdown-item'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the nav font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),										
						array(
                            'id'          => 'typography-a-hover-navmenu-sub-mobile',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sub Menu Item Hover', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'font-style'  => false,
							'font-family' => false,
							'font-size'   => false,
							'font-weight'   => true,
							'text-align'   => false,
                            'line-height' => false,
                            'output'      => array('body.is-mobile .navbar .dropdown-menu .dropdown:hover > .dropdown-item', 'body.is-mobile .navbar .dropdown-menu .dropdown-item.active', 'body.is-mobile .navbar .dropdown-menu .dropdown-item:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the nav font properties.', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_car_cat_contact',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Car & Product Taxonomy Pages Options', 'renax'),
			                'desc' => __('', 'renax')
			            ),	
						array(
                            'id'          => 'typographyfooter_car_post_title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Post Title', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.cars2 .car-list .item h3, .rn-woo-pro-title'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographyfooter_car_post_info',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Post Information', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.cars2 .car-list .item .content .cont .features span, .cars2 .car-list .item .content .cont .features p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographyfooter_car_post_price',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Post Price', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.cars2 .car-list .item .content .cont .book .price'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographyfooter_car_post_price_info',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Post Price Info', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.cars2 .car-list .item .content .cont .book .price span:not(.woocommerce-Price-amount, .woocommerce-Price-currencySymbol)'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_car_cat_cart_block',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Booking Block/ Add To Cart Block', 'renax'),
			                'desc' => __('Poroduct Details Page.', 'renax')
			            ),	
						array(
                            'id'          => 'typography_pro_dt_price',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Price', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.pt-pro-dt-chekout-price p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_pro_dt_price_info',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Price Info', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.car-details .sidebar-car .title h4 > span'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_pro_dt_label',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Label', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.variations th.label'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_pro_dt_select',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Select', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.variations .select2-container--default .select2-selection--single .select2-selection__rendered, body.woocommerce .picker__input, body.single-product input'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_pro_dt_placeholder',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Chrome Placeholder', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('body.single-product input::-webkit-input-placeholder'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_pro_dt_placeholder_fire',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Firefox Placeholder', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('body.single-product input:-moz-placeholder'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_post_page',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Post Page/ Index Pages Options', 'renax'),
			                'desc' => __('Footer Section', 'renax')
			            ),	
						array(
                            'id'          => 'typography_index_post_title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Post Title', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.blog2 .post-cont h5, .blog2 .post-cont h5 a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_index_post_meta',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Post Meta', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.blog2 .post-cont .category a, .blog2 .post-cont .calendar a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_footer_contact',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Footer Contact Options', 'renax'),
			                'desc' => __('Footer Section', 'renax')
			            ),	
						array(
                            'id'          => 'typographyfooter_con_info_title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Contact Item Title', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.footer-contact-link-wrapper h6'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('e.x: Phone', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographyfooter_con_info_dt',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Contact Item Info', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'line-height' => true,
							'text-transform' => true,
                            'output'      => array('.footer-contact-link-wrapper p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('e.x: +971 52-333-4444', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_page_widget',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Page Widgets', 'renax'),
			                'desc' => __('Page Sidebar Area.', 'renax')
			            ),	
						array(
                            'id'          => 'typographypage_wid_title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Default Widget Title', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.blog2-sidebar .widget-title h6'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographypage_wid_fancytitle',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Fancy Widget Title', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.cars2 .sidebar-list.rx-fancy-style-widget h6'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographypage_wid_list_tem',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget List Item', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.widget:not(.renax_about_widget) ul li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographypage_wid_tag_tem',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget Tags', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.widget .tagcloud a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_footer_widget',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Footer Widgets', 'renax'),
			                'desc' => __('Footer Section', 'renax')
			            ),	
						array(
                            'id'          => 'typographyfooter_wid_title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget Title', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.footer .widget .widget-title'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographyfooter_wid_p',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget Content', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.second-footer .widget-area .widget p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographyfooter_wid_li',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget List Item', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.footer-widget-area ul:not(.list-inline) li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographyfooter_wid_li_hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget List Item(Hover)', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.footer-widget-area ul:not(.list-inline) li a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_footer_copyright',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Footer Copyright', 'renax'),
			                'desc' => __('Footer Section', 'renax')
			            ),	
						array(
                            'id'          => 'typographyfooter_copyright',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Copyright Text', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.copyright p, .copyright'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typographyfooter_copyright_a',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Copyright Text URL', 'renax'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'output'      => array('.copyright a , .copyright p a, .copyright a:hover , .copyright p a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'renax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
							'id'       =>'opt_theme_footer_a_url_border',
							'type'     => 'color',
							'title'    => esc_html__( 'Copyright Text URL Border', 'renax' ),
							'subtitle' => esc_html__( '', 'renax' ),
							'desc'     => esc_html__( '', 'renax' ),
						),
						
                    )
                ) );
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-leaf',
                    'title'  => esc_html__( 'Social Options', 'renax' ),
                    'fields' => array(
					
						array(
							'id' => 'facebook',
							'type' => 'text',
							'title' => esc_html__('Facebook URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
						array(
							'id' => 'twitter',
							'type' => 'text',
							'title' => esc_html__('Twitter URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
						array(
							'id' => 'pinterest',
							'type' => 'text',
							'title' => esc_html__('Pinterest URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
						
						array(
							'id' => 'tiktok',
							'type' => 'text',
							'title' => esc_html__('TikTok URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
						array(
							'id' => 'dribbble',
							'type' => 'text',
							'title' => esc_html__('Dribbble URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
					
						array(
							'id' => 'linkedin',
							'type' => 'text',
							'title' => esc_html__('Linkedin URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
						array(
							'id' => 'youtube',
							'type' => 'text',
							'title' => esc_html__('Youtube URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
						array(
							'id' => 'vimeo',
							'type' => 'text',
							'title' => esc_html__('Vimeo URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
						array(
							'id' => 'slack',
							'type' => 'text',
							'title' => esc_html__('Slack ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
						array(
							'id' => 'instagram',
							'type' => 'text',
							'title' => esc_html__('Instagram URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
						array(
							'id' => 'tumblr',
							'type' => 'text',
							'title' => esc_html__('Tumblr URL ', 'renax'),
							'subtitle' => esc_html__('Write Social URL', 'renax'),
						),
					
						array(
							'id'       => 'opt_add_more_social',
							'type'     => 'multi_text',
							'title'    => esc_html__( 'Add More Social Icons.', 'renax' ),
							'subtitle' => esc_html__( '', 'renax' ),
							'desc'     => __( 'e.x: &lt;li&gt;&lt;a  target="_blank" rel="noopener" href="#"&gt;&lt;i class="fab fa-facebook-f"&gt;&lt;/i&gt;&lt;/a&gt;&lt;/li&gt;<br>Use <a href="https://fontawesome.com/v5/cheatsheet/pro/brands" target="_blank">Fontawesome</a> Icon Class', 'renax' ),
						),
					)
                ) );
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-brush',
                    'title'  => esc_html__( 'Footer Options', 'renax' ),
                    'fields' => array(
					
					array(
			                'id' => 'notice_footer_widget_col',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Footer Widget Option', 'renax'),
			                'desc' => esc_html__('', 'renax'),
			        ),
					array(
							'id' => 'en_footer_column_opt',
							'type' => 'button_set',
							'title' => esc_html__('Footer Widget Columns', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('3 Columns', 'renax'),
									'st2' => esc_html__('4 Columns', 'renax'),
							),
							'default'  => 'st1',
					),
					array(
			                'id' => 'notice_footer_contact',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Footer Contact Options', 'renax'),
			                'desc' => esc_html__('', 'renax'),
			        ),						
					array(
							'id' => 'en_footer_contact_opt',
							'type' => 'button_set',
							'title' => esc_html__('Footer Contact', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'renax'),
									'st2' => esc_html__('Enable', 'renax'),
							),
							'default'  => 'st1',
					),
					array(
							'id' => 'footer_phone_title',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Phone Text', 'renax'),
							'subtitle' => esc_html__('Ex: Phone', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2'),
					),																							
					array(
							'id' => 'ft_phn_number1',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Phone Number 1', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')								
					),					
					array(
							'id' => 'ft_phn_number2',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Phone Number 2', 'renax'),
							'subtitle' => esc_html__('(Optional)', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),
					array(
							'id' => 'footer_email_title',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Email Text', 'renax'),
							'subtitle' => esc_html__('Ex: Email', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2'),
					),
					array(
							'id' => 'ft_email_address1',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Email Address 1', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),
					
					array(
							'id' => 'ft_email_address2',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Email Address 2', 'renax'),
							'subtitle' => esc_html__('(Optional)', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),
					array(
							'id' => 'footer_address_title',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Address Text', 'renax'),
							'subtitle' => esc_html__('Ex:  Our Address ', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2'),
					),	
					array(
							'id' => 'ft_address1',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Address Line 1', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),	
					array(
							'id' => 'ft_address1_link_url',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Address Line 1 URL', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),						
					array(
							'id' => 'ft_address2',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Address Line 2', 'renax'),
							'subtitle' => esc_html__('(Optional)', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),
					array(
							'id' => 'ft_address2_link_url',
							'type' => 'text',
							'output' => 'true',
							'title' => esc_html__('Address Line 2 URL', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),						
					array(
							'id' => 'ft_address_link_target',
							'type' => 'button_set',
							'title' => esc_html__('Link Target', 'renax'),
							'subtitle' => esc_html__('', 'renax'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Self', 'renax'),
									'st2' => esc_html__('Blank', 'renax'),
							),
							'default'  => 'st1',
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),	
					
					
					
					array(
							'id' => 'copyright',
							'type' => 'editor',
							'wpautop'=>true,
							'output' => 'true',
							'title' => esc_html__('Copyright text of the WebSite', 'renax'),
							'subtitle' => esc_html__('Write a Copyright text of your WebSite', 'renax'),
							'default'          => '&#169;[renax_year] <a href="https://themeforest.net/user/webredox/portfolio">webRedox</a>. All rights reserved.',
							'args'   => array(
								'teeny'            => true,
								'textarea_rows'    => 10
							)
					),
					
					array(
						'id' => 'notice_site_to_top',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Scroll To Top Button Option', 'renax'),
						'desc' => esc_html__('Enable/Disable to top button.', 'renax'),
					),
							
					array(
						'id' => 'enable_scroll_top',
						'type' => 'button_set',
						'title' => esc_attr__('Scroll To Top Button', 'renax'),
						'subtitle' => esc_attr__('', 'renax'),
						'desc' => '',
						'options' => array(
							'st1'=> esc_html__('Enable', 'renax'),
							'st2' => esc_html__('Disable', 'renax'),
						),
						'default'  => 'st1'
					),	

                    )
                ) );
				
				
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-key',
                    'title'  => esc_html__( 'Documentation', 'renax' ),
                    'fields' => array(					
					
					array(
							'id' => 'docs',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_html__('Renax Theme Documentation', 'renax'),
							'desc' => __('<a href="http://webredox.net/doc/renax" target="_blank">Click Here</a> To get the theme documentation.', 'renax')
							
					),	

				)
                ));
				
				
    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    //if ( ! function_exists( 'compiler_action' ) ) {
		
    //}

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $return['error'] = $field;
                $field['msg']    = 'your custom error message';
            }

            if ( $warning == true ) {
                $return['warning'] = $field;
                $field['msg']      = 'your custom warning message';
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => esc_html__( 'Section via hook', 'renax' ),
                'desc'   => esc_html__( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'renax' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-renax plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }

